Juniper.ScreenOS
================

====== =============================================
Vendor `Juniper Networks <http://www.juniper.net/>`_
OS     ScreenOS
====== =============================================

Juniper.ScreenOS profile supports Juniper ScreenOS-based series of firewalls (NetScreen, ISG, SSG)

Tested Equipment
----------------
.. supported:: Juniper.ScreenOS
